
rm(list = ls())
library(readxl)
library(stats)
library(coefplot)
library(car)
library(corrplot)
library(ggplot2)
library(gridExtra)
library(lubridate)
library(anytime)
library(dplyr)
library(plm)
library(lme4)
library(lmerTest)
library(lmtest)
library(rugarch)

setwd("/Users/edmundaslapenas/Desktop/Progress Master")
data_2year <- "long_data_sust_control_2.xlsx"
data_2year <- read_excel(data_2year)
head(data_2year)

#### convert date ######
data_2year$Date <- anytime(data_2year$Date)
head(data_2year)


#### various plots of sustainability ragings ####
ggplot(data_2year, aes(x = `Fund Type`, y = as.numeric(`Sustainability rating`), fill = `Fund Type`)) +
  geom_boxplot() +
  labs(title = "Sustainability Ratings Distribution",
       x = "Fund Type",
       y = "Sustainability Rating") +
  theme_minimal()

ggplot(data_2year, aes(x = `Fund Type`, y = as.numeric(`Sustainability rating`), fill = `Fund Type`)) +
  geom_boxplot() +
  facet_wrap(~`Date`) +
  labs(title = "Sustainability Ratings Distribution Over Time",
       x = "Fund Type",
       y = "Sustainability Rating") +
  theme_minimal()

mean_ratings <- data_2year %>%
  filter(`Fund Type` %in% c("Article 8", "Index")) %>%
  mutate(`Sustainability rating` = as.numeric(`Sustainability rating`)) %>%
  group_by(`Fund Type`, `Date`) %>%
  summarize(mean_rating = mean(`Sustainability rating`, na.rm = TRUE))

ggplot(mean_ratings, aes(x = `Date`, y = mean_rating, color = `Fund Type`, group = `Fund Type`)) +
  geom_line(size = 1) +
  geom_point(size = 3) +
  labs(title = "Mean Sustainability Ratings Over Time",
       x = "Time Period",
       y = "Mean Sustainability Rating") +
  theme_minimal()

median_ratings <- data_2year %>%
  filter(`Fund Type` %in% c("Article 8", "Index")) %>%
  mutate(`Sustainability rating` = as.numeric(`Sustainability rating`)) %>%
  group_by(`Fund Type`, `Date`) %>%
  summarize(median_rating = median(`Sustainability rating`, na.rm = TRUE))


ggplot(median_ratings, aes(x = `Date`, y = median_rating, color = `Fund Type`, group = `Fund Type`)) +
  geom_line(size = 1) +
  geom_point(size = 3) +
  labs(title = "Median Sustainability Ratings Over Time",
       x = "Time Period",
       y = "Median Sustainability Rating") +
  theme_minimal()

############ Panel regression and analysis #############

head(data_2year)
# Convert the 'Sustainability rating' column to numeric
data_2year$`Sustainability rating` <- as.numeric(data_2year$`Sustainability rating`)
head(data_2year)

# Create a numeric variable to represent the fund types (0 = Index, 1 = Article 8)
data_2year$Fund_Type_Numeric <- ifelse(data_2year$`Fund Type` == "Article 8", 1, 0)

# Create an id variable for each fund
data_2year$ID <- as.factor(1:nrow(data_2year))

# unique fund ids (Fund_ID)
fund_ids <- data_2year %>%
  distinct(`Fund name`) %>%
  mutate(Fund_ID = row_number()) %>%
  select(`Fund name`, Fund_ID)

data_2year <- left_join(data_2year, fund_ids, by = "Fund name")

##### Regression of sustainability ratings. The fixed effect is Fund_Type_Numeric, the random effects are Fund_ID and Date

mixed_effects <- lmer(`Sustainability rating` ~ Fund_Type_Numeric + (1|Fund_ID) + (1|`Date`), data = data_2year)
summary(mixed_effects)

# Residual plots (model - mixed_effects) 

residuals_mf <- data.frame(Residuals = residuals(mixed_effects))
ggplot(residuals_mf, aes(Residuals)) +
  geom_histogram(fill='blue', color='black', alpha=0.7, bins=30) +
  theme_minimal() +
  labs(title="Histogram of Residuals")

ggplot(residuals_mf, aes(sample = Residuals)) +
  stat_qq() +
  stat_qq_line() +
  theme_minimal() +
  labs(title="Q-Q Plot of Residuals")

fitted_mf <- data.frame(Residuals = residuals(mixed_effects), Fitted = fitted(mixed_effects))

ggplot(fitted_mf, aes(x = Fitted, y = Residuals)) +
  geom_point(shape = 1) +
  geom_hline(yintercept=0, color = "red") +
  theme_minimal() +
  labs(x="Fitted Values", y="Residuals", title="Residuals vs Fitted Values")

###### Regression of sustainability ratings, where time (Date) is now fixed-effect

fixed_effects <- lm(`Sustainability rating` ~ Fund_Type_Numeric + Date, data = data_2year)
summary(fixed_effects)


data_2year %>%
  group_by(`Fund Type`, `Date`) %>%
  summarise(mean_sustainability = mean(`Sustainability rating`, na.rm = TRUE),
            median_sustainability = median(`Sustainability rating`, na.rm = TRUE),
            min_sustainability = min(`Sustainability rating`, na.rm = TRUE),
            max_sustainability = max(`Sustainability rating`, na.rm = TRUE),
            sd_sustainability = sd(`Sustainability rating`, na.rm = TRUE),
            count = n())

data_2year %>%
  group_by(`Fund Type`) %>%
  summarise(mean_sustainability = mean(`Sustainability rating`, na.rm = TRUE),
            median_sustainability = median(`Sustainability rating`, na.rm = TRUE),
            min_sustainability = min(`Sustainability rating`, na.rm = TRUE),
            max_sustainability = max(`Sustainability rating`, na.rm = TRUE))

############ Regression analysis including control variables (Avr.m.cap, Fund_size, Monthly.Ret, PB, ROE, PE, Draw_down) #################

head(data_2year)

#### convert control variables (Avr.m.cap, Fund_size, Monthly.Ret, PB, ROE, PE, Draw_down) to numeric
control_variables <- data_2year %>%
  select(Avr.m.cap, Fund_size, Monthly.Ret, PB, ROE, PE, Draw_down) %>%
  mutate_all(as.numeric)
data_2year <- data_2year %>%
  mutate_at(vars(Avr.m.cap, Fund_size, Monthly.Ret, PB, ROE, PE, Draw_down), as.numeric)
head(data_2year)

mixed_effects_all <- lmer(`Sustainability rating` ~ Fund_Type_Numeric + Avr.m.cap + Fund_size + Monthly.Ret + PB + ROE + Draw_down + (1|Fund_ID) + (1|`Date`), data = data_2year)
summary(mixed_effects_all)

######################### Autocorrelation analysis #########################

# Extract the residuals from your model
residuals_mixed_effects_all <- residuals(mixed_effects_all)

# Compute and plot the autocorrelation function
acf(residuals_mixed_effects_all)
vif(mixed_effects_all)

# Convert residuals to a data frame for ggplot
residuals_mixed_effects_all_df<- data.frame(residuals_mixed_effects_all)

# Make a histogram using ggplot
ggplot(residuals_mixed_effects_all_df, aes(residuals_mixed_effects_all)) +
  geom_histogram(binwidth = .5, fill = "dodgerblue3", colour = "white") +
  labs(x = "Residuals", y = "Count") +
  theme_minimal() +
  ggtitle("Histogram of Residuals")


########### cheching for multicolinearity among the variables ############

# Handle missing data with na.omit() or na.exclude()
data_2year_complete <- na.omit(data_2year)

cor_matrix_lm_model_all <- cor(data_2year_complete[, c("Fund_Type_Numeric", "Avr.m.cap", "Fund_size", "Monthly.Ret", 
                                                       "PB", "ROE", "Draw_down")])
# print the correlation matrix
print(cor_matrix_lm_model_all)

vif(lm_model_all)

####### fit of the model 

# calculate AIC
aic_mixed_effects <- AIC(mixed_effects)
print(paste("AIC for mixed_effects: ", aic_mixed_effects))
aic_mixed_effects_all <- AIC(mixed_effects_all)
print(paste("AIC for mixed_effects_all: ", aic_mixed_effects_all))


# calculate BIC
bic_mixed_effects <- BIC(mixed_effects)
print(paste("BIC for mixed_effects: ", bic_mixed_effects))
bic_mixed_effects_all <- BIC(mixed_effects_all)
print(paste("BIC for mixed_effects_all: ", bic_mixed_effects_all))

###### checking for better fit ####

mixed_effects_all_sign <- lmer(`Sustainability rating` ~ Fund_Type_Numeric + PB + ROE + Draw_down + (1|Fund_ID) + (1|`Date`), data = data_2year)
summary(mixed_effects_all_sign)

aic_mixed_effects_sign <- AIC(mixed_effects_all_sign)
print(paste("AIC for mixed_effects: ", aic_mixed_effects_sign))

bic_mixed_effects_sign <- BIC(mixed_effects_all_sign)
print(paste("BIC for mixed_effects: ", bic_mixed_effects_sign))

############ Autocorrelation - fixed date

mixed_effects_fixed_date <- lmer(`Sustainability rating` ~ Fund_Type_Numeric + Avr.m.cap + Fund_size + Monthly.Ret + PB + ROE + Draw_down + (1|Fund_ID), data = data_2year)
summary(mixed_effects_fixed_date)

# Compute AIC for mixed_effects_fixed_date
aic_mixed_effects_fixed_date = AIC(mixed_effects_fixed_date)

# Compute BIC for mixed_effects_fixed_date
bic_mixed_effects_fixed_date = BIC(mixed_effects_fixed_date)

# Print the results
cat("AIC for mixed_effects_fixed_date: ", aic_mixed_effects_fixed_date, "\n")
cat("BIC for mixed_effects_fixed_date: ", bic_mixed_effects_fixed_date, "\n")

# Extract residuals
residuals_mixed_effects_fixed_date <- residuals(mixed_effects_fixed_date)

# Plot Autocorrelation Function (ACF)
acf(residuals_mixed_effects_fixed_date)

######### Autocorrelation - including lagg

##### creating lag

data_2year$lagged_Sustainability_rating <- dplyr::lag(data_2year$`Sustainability rating`, 1)
head(data_2year)

mixed_effects_all_lagged <- lmer(`Sustainability rating` ~ lagged_Sustainability_rating + Fund_Type_Numeric + Avr.m.cap + Fund_size + Monthly.Ret + PB + ROE + Draw_down + (1|Fund_ID) + (1|`Date`), data = data_2year)
summary(mixed_effects_all_lagged)

# AIC and BIC
cat("AIC for mixed_effects_all_lagged: ", AIC(mixed_effects_all_lagged), "\n")
cat("BIC for mixed_effects_all_lagged: ", BIC(mixed_effects_all_lagged), "\n")

# ACF of residuals
mixed_effects_all_lagged_resid <- residuals(mixed_effects_all_lagged)
acf(mixed_effects_all_lagged_resid)

###### Autocorrelation - lag + fixed time

# Build the mixed-effects model with time as fixed effect and the lagged variable
mixed_effects_fixed_date_lagged <- lmer(`Sustainability rating` ~ lagged_Sustainability_rating + Fund_Type_Numeric + Avr.m.cap + Fund_size + Monthly.Ret + PB + ROE + Draw_down + Date + (1|Fund_ID), data = data_2year)

# Summary of the model
summary(mixed_effects_fixed_date_lagged)

cat("AIC for mixed_effects_fixed_date_lagged: ", AIC(mixed_effects_fixed_date_lagged), "\n")
cat("BIC for mixed_effects_fixed_date_lagged: ", BIC(mixed_effects_fixed_date_lagged), "\n")

# ACF of residuals
mixed_effects_fixed_date_lagged_resid <- residuals(mixed_effects_fixed_date_lagged)
acf(mixed_effects_fixed_date_lagged_resid)

########### regression model from 2021 December

# Create a new 'Date_only' column
data_2year$Date_only <- as.Date(data_2year$Date)

# Subset the data
data_dec_2021_onwards <- subset(data_2year, Date_only >= as.Date("2021-12-01"))

mixed_effects_dec2021_onwards <- lmer(`Sustainability rating` ~ lagged_Sustainability_rating + Fund_Type_Numeric + Avr.m.cap + Fund_size + Monthly.Ret + PB + ROE + Draw_down + (1|Fund_ID) + (1|`Date`), data = data_dec_2021_onwards)
summary(mixed_effects_dec2021_onwards)

# AIC and BIC
cat("AIC for mixed_effects_dec2021_onwards: ", AIC(mixed_effects_dec2021_onwards), "\n")
cat("BIC for mixed_effects_dec2021_onwards: ", BIC(mixed_effects_dec2021_onwards), "\n")

# Residuals from the model
residuals_dec2021_onwards <- residuals(mixed_effects_dec2021_onwards)

# ACF plot
acf(residuals_dec2021_onwards, main = "ACF of Residuals (Dec 2021 onwards)")
